@@ -22,7 +22,7 @@ our @EXPORT = qw(
 our @ISA = qw(Exporter);
 
 # Set the package version. 
-our $VERSION = '0.16';
+our $VERSION = '0.17';
 
 # Load the Perl modules.
 use POSIX qw(ttyname);
@@ -132,31 +132,6 @@ our %termhash = (
     "xvt"                    => "Xvt"   
 );
 
-# ============================================================================ #
-# Subroutine check_prereq                                                      # 
-#                                                                              #
-# Description:                                                                 #
-# Check package prerequisites.                                                 #
-# ============================================================================ #
-sub check_prereq {
-    # Check if Linux command which exists.
-    if (! -x "/bin/which" || ! -x "/usr/bin/which") {
-        die "Linux command 'which' does not exist.\n";
-    };
-    # Check if grep, users and ps exists.
-    die unless `which grep`;
-    die unless `which users`;
-    die unless `which ps`;
-    # Check if passwd exists.
-    if (! -e $FN_PASSWD) {
-        die "$!, $FN_PASSWD not exists.\n";
-    };
-    # Check if shells exists.
-    if (! -e $FN_SHELLS) {
-        die "$!, $FN_SHELLS not exists.\n";
-    };
-};
-
 # ============================================================================ #
 # Subroutine trim                                                              #
 #                                                                              #
